==> aws_solutions_constructs_aws_cloudfront_apigateway_lambda-2.92.0-py3-none-any.whl: package/lib/index.d.ts <==
/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import * as api from 'aws-cdk-lib/aws-apigateway';
import * as lambda from 'aws-cdk-lib/aws-lambda';
import * as cloudfront from 'aws-cdk-lib/aws-cloudfront';
import * as logs from 'aws-cdk-lib/aws-logs';
import * as s3 from 'aws-cdk-lib/aws-s3';
import * as iam from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
/**
 * @summary The properties for the CloudFrontToApiGatewayToLambda Construct
 */
export interface CloudFrontToApiGatewayToLambdaProps {
    /**
     * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
     *
     * @default - None
     */
    readonly existingLambdaObj?: lambda.Function;
    /**
     * Optional user provided props to override the default props for the Lambda function.
     *
     * @default - Default props are used
     */
    readonly lambdaFunctionProps?: lambda.FunctionProps;
    /**
     * User provided props to override the default props for the API Gateway. As of release
     * 2.48.0, clients must include this property with defaultMethodOptions: { authorizationType: string } specified.
     * See Issue1043 in the github repo https://github.com/awslabs/aws-solutions-constructs/issues/1043
     *
     * @default - defaultMethodOptions/authorizationType is required, for other, unspecified values the
     * default props are used
     */
    readonly apiGatewayProps: api.LambdaRestApiProps | any;
    /**
     * Whether to create a Usage Plan attached to the API. Must be true if
     * apiGatewayProps.defaultMethodOptions.apiKeyRequired is true
     *
     * @default - true (to match legacy behavior)
     */
    readonly createUsagePlan?: boolean;
    /**
     * Optional user provided props to override the default props
     *
     * @default - Default props are used
     */
    readonly cloudFrontDistributionProps?: cloudfront.DistributionProps | any;
    /**
     * Optional user provided props to turn on/off the automatic injection of best practice HTTP
     * security headers in all responses from cloudfront.
     * Turning this on will inject default headers and is mutually exclusive with passing custom security headers
     * via the responseHeadersPolicyProps parameter.
     *
     * @default - true
     */
    readonly insertHttpSecurityHeaders?: boolean;
    /**
     * Optional user provided configuration that cloudfront applies to all http responses.
     * Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or
     * ResponseHeadersCorsBehavior to the cloudfront distribution.
     *
     * Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers
     * via `insertHttpSecurityHeaders` prop. Will throw an error if both `insertHttpSecurityHeaders` is set to `true`
     * and ResponseSecurityHeadersBehavior is passed.
     *
     * @default - undefined
     */
    readonly responseHeadersPolicyProps?: cloudfront.ResponseHeadersPolicyProps;
    /**
     * Optional user provided props to override the default props for the CloudWatchLogs LogGroup.
     *
     * @default - Default props are used
     */
    readonly logGroupProps?: logs.LogGroupProps;
    /**
     * Optional user provided props to override the default props for the CloudFront Logging Bucket.
     *
     * @default - Default props are used
     */
    readonly cloudFrontLoggingBucketProps?: s3.BucketProps;
}
export declare class CloudFrontToApiGatewayToLambda extends Construct {
    readonly cloudFrontWebDistribution: cloudfront.Distribution;
    readonly cloudFrontFunction?: cloudfront.Function;
    readonly cloudFrontLoggingBucket?: s3.Bucket;
    readonly apiGateway: api.RestApi;
    readonly apiGatewayCloudWatchRole?: iam.Role;
    readonly apiGatewayLogGroup: logs.LogGroup;
    readonly lambdaFunction: lambda.Function;
    /**
     * @summary Constructs a new instance of the CloudFrontToApiGatewayToLambda class.
     * @param {Construct} scope - represents the scope for all the resources.
     * @param {string} id - this is a a scope-unique id.
     * @param {CloudFrontToApiGatewayToLambdaProps} props - user provided props for the construct
     * @since 0.8.0
     * @access public
     */
    constructor(scope: Construct, id: string, props: CloudFrontToApiGatewayToLambdaProps);
}

==> aws_solutions_constructs_aws_cloudfront_apigateway_lambda-2.97.0-py3-none-any.whl: package/lib/index.d.ts <==
/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import * as api from 'aws-cdk-lib/aws-apigateway';
import * as lambda from 'aws-cdk-lib/aws-lambda';
import * as cloudfront from 'aws-cdk-lib/aws-cloudfront';
import * as logs from 'aws-cdk-lib/aws-logs';
import * as s3 from 'aws-cdk-lib/aws-s3';
import * as iam from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
/**
 * @summary The properties for the CloudFrontToApiGatewayToLambda Construct
 */
export interface CloudFrontToApiGatewayToLambdaProps {
    /**
     * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
     *
     * @default - None
     */
    readonly existingLambdaObj?: lambda.Function;
    /**
     * Optional - user provided props to override the default props for the Lambda function. Providing both this and `existingLambdaObj` is an error.
     *
     * @default - Default props are used
     */
    readonly lambdaFunctionProps?: lambda.FunctionProps;
    /**
     * User provided props to override the default props for the API Gateway. As of release
     * 2.48.0, clients must include this property with defaultMethodOptions: { authorizationType: string } specified.
     * See Issue1043 in the github repo https://github.com/awslabs/aws-solutions-constructs/issues/1043
     *
     * @default - defaultMethodOptions/authorizationType is required, for other, unspecified values the
     * default props are used
     */
    readonly apiGatewayProps: api.LambdaRestApiProps | any;
    /**
     * Whether to create a Usage Plan attached to the API. Must be true if
     * apiGatewayProps.defaultMethodOptions.apiKeyRequired is true
     *
     * @default - true (to match legacy behavior)
     */
    readonly createUsagePlan?: boolean;
    /**
     * Optional user provided props to override the default props
     *
     * @default - Default props are used
     */
    readonly cloudFrontDistributionProps?: cloudfront.DistributionProps | any;
    /**
     * Optional user provided props to turn on/off the automatic injection of best practice HTTP
     * security headers in all responses from cloudfront.
     * Turning this on will inject default headers and is mutually exclusive with passing custom security headers
     * via the responseHeadersPolicyProps parameter.
     *
     * @default - true
     */
    readonly insertHttpSecurityHeaders?: boolean;
    /**
     * Optional user provided configuration that cloudfront applies to all http responses.
     * Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or
     * ResponseHeadersCorsBehavior to the cloudfront distribution.
     *
     * Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers
     * via `insertHttpSecurityHeaders` prop. Will throw an error if both `insertHttpSecurityHeaders` is set to `true`
     * and ResponseSecurityHeadersBehavior is passed.
     *
     * @default - undefined
     */
    readonly responseHeadersPolicyProps?: cloudfront.ResponseHeadersPolicyProps;
    /**
     * Optional user provided props to override the default props for the CloudWatchLogs LogGroup.
     *
     * @default - Default props are used
     */
    readonly logGroupProps?: logs.LogGroupProps;
    /**
     * Optional user provided props to override the default props for the CloudFront Logging Bucket.
     *
     * @default - Default props are used
     */
    readonly cloudFrontLoggingBucketProps?: s3.BucketProps;
}
export declare class CloudFrontToApiGatewayToLambda extends Construct {
    readonly cloudFrontWebDistribution: cloudfront.Distribution;
    readonly cloudFrontFunction?: cloudfront.Function;
    readonly cloudFrontLoggingBucket?: s3.Bucket;
    readonly apiGateway: api.RestApi;
    readonly apiGatewayCloudWatchRole?: iam.Role;
    readonly apiGatewayLogGroup: logs.LogGroup;
    readonly lambdaFunction: lambda.Function;
    /**
     * @summary Constructs a new instance of the CloudFrontToApiGatewayToLambda class.
     * @param {Construct} scope - represents the scope for all the resources.
     * @param {string} id - this is a a scope-unique id.
     * @param {CloudFrontToApiGatewayToLambdaProps} props - user provided props for the construct
     * @since 0.8.0
     * @access public
     */
    constructor(scope: Construct, id: string, props: CloudFrontToApiGatewayToLambdaProps);
}
